@@ -1,5 +1,5 @@
 package Git::Repository;
-$Git::Repository::VERSION = '1.315';
+$Git::Repository::VERSION = '1.318';
 use warnings;
 use strict;
 use 5.006;
@@ -7,9 +7,21 @@ use 5.006;
 use Carp;
 use File::Spec;
 use Cwd qw( cwd realpath );
-use Scalar::Util qw( looks_like_number );
 
 use Git::Repository::Command;
+use Git::Version::Compare qw( :ops );
+
+# helper function
+sub _abs_path {
+    my ( $path, $base ) = @_;
+    my $abs_path = File::Spec->rel2abs( $path, $base );
+
+    # normalize, but don't die on Win32 if the path doesn't exist
+    eval { $abs_path = realpath($abs_path); };
+    return $abs_path;
+}
+
+use namespace::clean;
 
 # a few simple accessors
 for my $attr (qw( git_dir work_tree options )) {
@@ -25,16 +37,6 @@ sub wc_path {
     croak "wc_path() is obsolete, please use work_tree() instead";
 }
 
-# helper function
-sub _abs_path {
-    my ( $path, $base ) = @_;
-    my $abs_path = File::Spec->rel2abs( $path, $base );
-
-    # normalize, but don't die on Win32 if the path doesn't exist
-    eval { $abs_path = realpath($abs_path); };
-    return $abs_path;
-}
-
 #
 # support for loading plugins
 #
@@ -210,74 +212,18 @@ sub version {
             =~ /git version (.*)/g )[0];
 }
 
-sub _version_gt {
-    my ( $v1, $v2 ) = @_;
-    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
-
-    my @v1 = split /\./, $v1;
-    my @v2 = split /\./, $v2;
-
-    # pick up any dev parts
-    my @dev1 = splice @v1, -2 if substr( $v1[-1], 0, 1 ) eq 'g';
-    my @dev2 = splice @v2, -2 if substr( $v2[-1], 0, 1 ) eq 'g';
-
-    # skip to the first difference
-    shift @v1, shift @v2 while @v1 && @v2 && $v1[0] eq $v2[0];
-
-    # we're comparing dev versions with the same ancestor
-    if ( !@v1 && !@v2 ) {
-        @v1 = @dev1;
-        @v2 = @dev2;
+BEGIN {
+    for my $op ( qw( lt gt le ge eq ne ) ) {
+        no strict 'refs';
+        *{"version_$op"} = eval << "OP";
+sub {
+    my \$r = shift;
+    my \@o;
+    my (\$v) = grep !( ref && ref eq 'HASH' ? push \@o, \$_ : 0 ), \@_;
+    return ${op}_git( \$r->version(\@o), \$v );
+}
+OP
     }
-
-    # prepare the bits to compare
-    ( $v1, $v2 ) = ( $v1[0] || 0, $v2[0] || 0 );
-
-    # rcX is less than any number
-    return looks_like_number($v1)
-             ? looks_like_number($v2) ? $v1 > $v2 : 1
-             : looks_like_number($v2) ? ''        : $v1 gt $v2;
-}
-
-# every op is a combination of eq and gt
-sub version_eq {
-    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $v1 = $r->version(@o);
-    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
-    return $v1 eq $v2;
-}
-
-sub version_ne {
-    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $v1 = $r->version(@o);
-    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
-    return $v1 ne $v2;
-}
-
-sub version_gt {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    return _version_gt( $r->version(@o), $v );
-}
-
-sub version_le {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    return !_version_gt( $r->version(@o), $v );
-}
-
-sub version_lt {
-    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $v1 = $r->version(@o);
-    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
-    return $v1 ne $v2
-        && !_version_gt( $v1, $v2 );
-}
-
-sub version_ge {
-    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $v1 = $r->version(@o);
-    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
-    return $v1 eq $v2
-        || _version_gt( $v1, $v2 );
 }
 
 1;
@@ -541,33 +487,8 @@ The methods are:
 
 All those methods also accept an option hash, just like the others.
 
-Note that in the C<git.git> repository, C<v1.0.1> and C<v1.0.2> are
-lightweight tags that points respectively to C<v1.0.0a> and C<v1.0.0b>.
-As of Git::Repository 1.314, the comparison code internally converts
-C<v1.0.0a> and C<v1.0.0b> to their numerical equivalent before performing
-the comparison.
-
-Prior to C<1.4.0-rc1> (June 2006), compiling a development version of git
-would lead C<git --version> to output C<1.x-GIT> (with C<x> in C<0 .. 3>),
-which would make comparing versions that are very close a futile exercise.
-
-Other issues exist when comparing development version numbers with one
-another. For example, C<1.7.1.1> is greater than both C<1.7.1.1.gc8c07>
-and C<1.7.1.1.g5f35a>, and C<1.7.1> is less than both. Obviously,
-C<1.7.1.1.gc8c07> will compare as greater than C<1.7.1.1.g5f35a>
-(asciibetically), but in fact these two version numbers cannot be
-compared, as they are two siblings children of the commit tagged
-C<v1.7.1>).
-
-If one were to compute the set of all possible version numbers (as returned
-by C<git --version>) for all git versions that can be compiled from each
-commit in the F<git.git> repository, the result would not be a totally ordered
-set. Big deal.
-
-Also, don't be too precise when requiring the minimum version of Git that
-supported a given feature. The precise commit in git.git at which a given
-feature was added doesn't mean as much as the release branch in which that
-commit was merged.
+The actual version-comparison logic is managed by L<Git::Version::Compare>.
+Check its documentation for details.
 
 =head1 PLUGIN SUPPORT
 
@@ -688,7 +609,7 @@ L<Git::Sub> doesn't support working with streams.
 upon request of the author of L<Git::Raw>.)
 
 L<Git::Raw>
-provides bindings to L<libgit2|http://libgit2.github.com/>, a pure C
+provides bindings to L<libgit2|https://libgit2.github.io/>, a pure C
 implementation of the Git core methods. Most of the functions provided by
 libgit2 are available. If you have complex workflows, or even if speed is of
 the essence, this may be a more attractive solution than shelling out to git.
@@ -732,9 +653,13 @@ L<http://search.cpan.org/dist/Git-Repository>
 
 =back
 
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
 =head1 COPYRIGHT
 
-Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2016 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
