@@ -1,5 +1,5 @@
 package Git::Repository::Plugin;
-$Git::Repository::Plugin::VERSION = '1.314';
+$Git::Repository::Plugin::VERSION = '1.318';
 use strict;
 use warnings;
 use 5.006;
@@ -30,20 +30,12 @@ sub _keywords {
 
 1;
 
-# ABSTRACT: Base class for Git::Repository plugins
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Git::Repository::Plugin - Base class for Git::Repository plugins
 
-=head1 VERSION
-
-version 1.314
-
 =head1 SYNOPSIS
 
     package Git::Repository::Plugin::Hello;
@@ -98,6 +90,10 @@ avoid name clashes between plugins) is C<_plugin_I<name>_I<attribute>>,
 where I<name> is the plugin lowercase name, and I<attribute> is the
 attribute name.
 
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Todd Rinaldo, who wanted to add more methods to
@@ -112,23 +108,9 @@ team.
 
 Further improvements to the plugin system proposed by Aristotle Pagaltzis.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2016 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
